/******************************************************************************/
/* COPYRIGHT: Copyright (C) International Business Machines Corp., 1997       */
/*                                                                            */
/* DISCLAIMER OF WARRANTIES:                                                  */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is not part of any standard IBM product   */
/*   and is provided to you solely for the purpose of assisting you in the    */
/*   development of your applications.  The code is provided "AS IS",         */
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
/******************************************************************************/

import	java.awt.*;
import 	java.awt.event.*;
import	java.applet.Applet;




class BorderLayoutTest extends Frame
				implements WindowListener

{
	private Button		north  = new Button("North");
	private Button		south  = new Button("South");
	private Button		east   = new Button("East");
	private Button		west   = new Button("West");
	private Button		center = new Button("Center");

	private Panel		borderPanel = new Panel();
	private BorderLayout	borderLayout = new BorderLayout();
	private Panel		buttonPanel = new Panel();
	private FlowLayout	buttonLayout = new FlowLayout(FlowLayout.LEFT, 5, 5);


	private Button		northPlus  = new Button("North +");
	private Button		northMinus = new Button("North -");
	private Button		westPlus  = new Button("West +");
	private Button		westMinus = new Button("West -");

	private Button		vgapPlus = new Button("vgap +");
	private Button		vgapMinus = new Button("vgap -");
	private Button		hgapPlus = new Button("hgap +");
	private Button		hgapMinus = new Button("hgap -");

	private int			vgap = 0;
	private int			hgap = 0;
	private int			northFontSize = 20;
	private int			southFontSize = 20;
	private int			eastFontSize = 20;
	private int			westFontSize = 20;
	private int			centerFontSize = 60;	

	BorderLayoutTest()
	{
		super("BorderLayout Test");

		addWindowListener(this);
		
		borderPanel.setLayout(borderLayout);
		buttonPanel.setLayout(buttonLayout);

		north.setFont(new Font("Helvetica", Font.PLAIN, northFontSize));
		south.setFont(new Font("Helvetica", Font.PLAIN, southFontSize));
		east.setFont(new Font("Helvetica", Font.PLAIN, eastFontSize));
		west.setFont(new Font("Helvetica", Font.PLAIN, westFontSize));
		center.setFont(new Font("Helvetica", Font.PLAIN, centerFontSize));

		borderPanel.add("North", north);	
		borderPanel.add("South", south);
		borderPanel.add("East", east);
		borderPanel.add("West", west);
		borderPanel.add("Center", center);


		buttonPanel.add(vgapPlus);
		buttonPanel.add(vgapMinus);
		buttonPanel.add(hgapPlus);
		buttonPanel.add(hgapMinus);
		buttonPanel.add(northPlus);
		buttonPanel.add(northMinus);
		buttonPanel.add(westPlus);
		buttonPanel.add(westMinus);


		add("Center", borderPanel);
		add("South", buttonPanel);	

            // Increase vgap
		vgapPlus.addActionListener(
			new ActionListener ()
			{
				public void actionPerformed(ActionEvent e)
				{
					vgap +=5;
					borderLayout.setVgap(vgap);
					borderLayout.layoutContainer(borderPanel);
				}
			}
		);

            // Decrease vgap
		vgapMinus.addActionListener(
			new ActionListener ()
			{
				public void actionPerformed(ActionEvent e)
				{
					if(vgap>5)
						vgap -=5;
					else
						vgap = 0;
					borderLayout.setVgap(vgap);
					borderLayout.layoutContainer(borderPanel);				}
			}
		);

            // Increase hgap
		hgapPlus.addActionListener(
			new ActionListener ()
			{
				public void actionPerformed(ActionEvent e)
				{
					hgap +=5;
					borderLayout.setHgap(hgap);
					borderLayout.layoutContainer(borderPanel);
				}
			}
		);

            // Decrease hgap
		hgapMinus.addActionListener(
			new ActionListener ()
			{
				public void actionPerformed(ActionEvent e)
				{
					if(hgap>5)
						hgap -=5;
					else
						hgap = 0;
					borderLayout.setHgap(hgap);
					borderLayout.layoutContainer(borderPanel);
				}
			}
		);
	// Decrease North Font
		northMinus.addActionListener(
			new ActionListener ()
			{
				public void actionPerformed(ActionEvent e)
				{
					if(northFontSize>10)
						northFontSize -=10;
					else
						northFontSize = 10;
					north.setFont(new Font("Helvetica", 
								Font.PLAIN, northFontSize));
					borderLayout.invalidateLayout(borderPanel);
					borderLayout.layoutContainer(borderPanel);
					borderPanel.repaint();				}
			}
		);

	// Increase North Font
		northPlus.addActionListener(
			new ActionListener ()
			{
				public void actionPerformed(ActionEvent e)
				{
					northFontSize += 10;
					north.setFont(new Font("Helvetica", 
								Font.PLAIN, northFontSize));
					borderLayout.invalidateLayout(borderPanel);
					borderLayout.layoutContainer(borderPanel);
					borderPanel.repaint();				}
			}
		);

	// Decrease West Font
		westMinus.addActionListener(
			new ActionListener ()
			{
				public void actionPerformed(ActionEvent e)
				{
					if(westFontSize>10)
						westFontSize -=10;
					else
						westFontSize = 10;
					west.setFont(new Font("Helvetica", 
								Font.PLAIN, westFontSize));
					borderLayout.invalidateLayout(borderPanel);
					borderLayout.layoutContainer(borderPanel);
					borderPanel.repaint();
				}
			}
		);

	// Increase West Font
		westPlus.addActionListener(
			new ActionListener ()
			{
				public void actionPerformed(ActionEvent e)
				{
					westFontSize += 10;
					west.setFont(new Font("Helvetica", 
								Font.PLAIN, westFontSize));
					borderLayout.invalidateLayout(borderPanel);
					borderLayout.layoutContainer(borderPanel);
					borderPanel.repaint();
				}
			}
		);

	}

	public static void main( String args[])
	{
		BorderLayoutTest flowTest = new BorderLayoutTest();
		flowTest.setSize(500, 350);
		flowTest.show();
	}

	public void windowClosing(WindowEvent event)
	{
		System.exit(0);
	}

	public void windowOpened(WindowEvent event) {}
	public void windowClosed(WindowEvent event) {}
	public void windowIconified(WindowEvent event) {}
	public void windowDeiconified(WindowEvent event) {}
	public void windowActivated(WindowEvent event) {}
	public void windowDeactivated(WindowEvent event) {}


}




