/******************************************************************************/
/* COPYRIGHT: Copyright (C) International Business Machines Corp., 1997       */
/*                                                                            */
/* DISCLAIMER OF WARRANTIES:                                                  */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is not part of any standard IBM product   */
/*   and is provided to you solely for the purpose of assisting you in the    */
/*   development of your applications.  The code is provided "AS IS",         */
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
/******************************************************************************/

import	java.awt.*;
import 	java.awt.event.*;
import	java.applet.Applet;




class GridBagLayoutTest extends Frame
				implements WindowListener, ActionListener

{
	private Button		button00 = new Button("(0,0) 1x1");
	private Button		button01 = new Button("(0,1) 1x1");
	private Button		button02 = new Button("(0,2) 1x1");
	private Button		button03 = new Button("(0,3) 1x1");
	private Button		button04 = new Button("(0,4) 1x1");
	private Button		button10 = new Button("(1,0) 1x1");
	private Button		button20 = new Button("(2,0) 1x1");
	private Button		button30 = new Button("(3,0) 1x1"); 
	private Button		button40 = new Button("(4,0) 1x1"); 
	private Button		button1x3 = new Button("(1,1) 1x3"); 
	private Button		button3x1 = new Button("(1,4) 3x1");
	private Button		button2x2 = new Button("(2,2) 2x2");
	private Panel		gridBagPanel = new Panel();
	private GridBagLayout	gridBagLayout = new GridBagLayout();
   private BorderLayout   borderLayout = new BorderLayout(0, 10);

	private GridLayout	buttonLayout = new GridLayout(2,5);
   private Panel     buttonPanel   = new Panel();

   private Button    noWeight  = new Button("all weight 0");
   private Button    fullWeight  = new Button("all weight 1");

   private Button    noWeightClick  = new Button("weight 0");
   private Button    quarterWeightClick  = new Button("weight .25");
   private Button    threeQuarterWeightClick  = new Button("weight .75");
   private Button    fullWeightClick  = new Button("weight 1");

   private Button    fontPlusClick  = new Button("Font +");
   private Button    fontMinusClick  = new Button("Font -");

   private Button    fillMinusClick  = new Button("Fill -");
   private Button    fillVertClick   = new Button("Fill V");
   private Button    fillHorzClick   = new Button("Fill H");
   private Button    fillPlusClick   = new Button("Fill +");

   private Button    anchorPlusClick   = new Button("Anchor +");

   private Button    padPlusClick   = new Button("Pad +");
   private Button    padMinusClick   = new Button("Pad -");

   private Button    insetsPlusClick   = new Button("Insets +");
   private Button    insetsMinusClick   = new Button("Insets -");


   private static final int NO_WEIGHT = 1;
   private static final int QUARTER_WEIGHT = 2;
   private static final int THREEQUARTER_WEIGHT = 3;
   private static final int FULL_WEIGHT = 4;
   private static final int FONTPLUS = 5;
   private static final int FONTMINUS = 6;
   private static final int FILLMINUS = 7;
   private static final int FILLVERT  = 8;
   private static final int FILLHORZ = 9;
   private static final int FILLPLUS = 10;
   private static final int ANCHORPLUS = 11;   
   private static final int PADPLUS = 12;
   private static final int PADMINUS = 13;   
   private static final int INSETSPLUS = 14;   
   private static final int INSETSMINUS = 15;   

   




   private int clickState = FONTPLUS;
   private int  anchorState = GridBagConstraints.CENTER;

	GridBagLayoutTest()
	{
		super("GridBagLayout Test");

		addWindowListener(this);
		
      setLayout(borderLayout);
		gridBagPanel.setLayout(gridBagLayout);

		button00.addActionListener(this);
		button01.addActionListener(this);
		button02.addActionListener(this);
		button03.addActionListener(this);
		button04.addActionListener(this);
		button10.addActionListener(this);
		button20.addActionListener(this);
		button30.addActionListener(this);
		button40.addActionListener(this);

		button1x3.addActionListener(this);
		button3x1.addActionListener(this);
		button2x2.addActionListener(this);

		GridBagConstraints gbc = new GridBagConstraints();
		gbc.gridx = 0;
		gbc.gridy = 0;
		gbc.gridwidth = 1;
		gbc.gridheight = 1;
      gbc.weightx = 1;
      gbc.weighty = 1;
		gbc.anchor = anchorState;
		gbc.fill = GridBagConstraints.BOTH;
		gridBagPanel.add(button00, gbc);

		gbc.gridx = 0;
		gbc.gridy = 1;
		gridBagPanel.add(button01, gbc);

		gbc.gridx = 0;
		gbc.gridy = 2;
		gridBagPanel.add(button02, gbc);

		gbc.gridx = 0;
		gbc.gridy = 3;
		gridBagPanel.add(button03, gbc);

		gbc.gridx = 0;
		gbc.gridy = 4;
		gridBagPanel.add(button04, gbc);

		gbc.gridx = 1;
		gbc.gridy = 0;
		gridBagPanel.add(button10, gbc);

		gbc.gridx = 2;
		gbc.gridy = 0;
		gridBagPanel.add(button20, gbc);

		gbc.gridx = 3;
		gbc.gridy = 0;
		gridBagPanel.add(button30, gbc);

		gbc.gridx = 4;
		gbc.gridy = 0;
		gridBagPanel.add(button40, gbc);

		gbc.gridx = 1;
		gbc.gridy = 1;
		gbc.gridwidth = 1;
		gbc.gridheight = 3;
		gridBagPanel.add(button1x3, gbc);

		gbc.gridx = 1;
		gbc.gridy = 4;
		gbc.gridwidth = 3;
		gbc.gridheight = 1;
		gridBagPanel.add(button3x1, gbc);

		gbc.gridx = 2;
		gbc.gridy = 2;
		gbc.gridwidth = 2;
		gbc.gridheight = 2;
		gridBagPanel.add(button2x2, gbc);

		add("Center", gridBagPanel);

      // Add controls
      buttonPanel.add(noWeight);
      buttonPanel.add(fullWeight);
      buttonPanel.add(noWeightClick);
      buttonPanel.add(quarterWeightClick);
      buttonPanel.add(threeQuarterWeightClick);
      buttonPanel.add(fullWeightClick);
      buttonPanel.add(fontPlusClick);
      buttonPanel.add(fontMinusClick);
      buttonPanel.add(fillMinusClick);
      buttonPanel.add(fillHorzClick);
      buttonPanel.add(fillVertClick);
      buttonPanel.add(fillPlusClick);   
	buttonPanel.add(anchorPlusClick);   
	buttonPanel.add(padPlusClick);   
	buttonPanel.add(padMinusClick);   
	buttonPanel.add(insetsPlusClick);   
	buttonPanel.add(insetsMinusClick);   

	buttonPanel.setLayout(buttonLayout);
      add("South", buttonPanel);


      // Change to FONTPLUS
		fontPlusClick.addActionListener( new ActionListener () {
				public void actionPerformed(ActionEvent e)
				{  clickState = FONTPLUS; } } );

      // Change to FONTMINUS
		fontMinusClick.addActionListener( new ActionListener () {
				public void actionPerformed(ActionEvent e)
				{  clickState = FONTMINUS; } } );

      // Change to FILLPLUS
		fillPlusClick.addActionListener( new ActionListener () {
				public void actionPerformed(ActionEvent e)
				{  clickState = FILLPLUS; } } );

      // Change to FILLVERT
		fillVertClick.addActionListener( new ActionListener () {
				public void actionPerformed(ActionEvent e)
				{  clickState = FILLVERT; } } );

      // Change to FILLHORZ
		fillHorzClick.addActionListener( new ActionListener () {
				public void actionPerformed(ActionEvent e)
				{  clickState = FILLHORZ; } } );

      // Change to FILLMINUS
		fillMinusClick.addActionListener( new ActionListener () {
				public void actionPerformed(ActionEvent e)
				{  clickState = FILLMINUS; } } );


      // Change to NO_WEIGHT
		noWeightClick.addActionListener( new ActionListener () {
				public void actionPerformed(ActionEvent e)
				{  clickState = NO_WEIGHT; } } );


      // Change to QUARTER_WEIGHT
		quarterWeightClick.addActionListener( new ActionListener () {
				public void actionPerformed(ActionEvent e)
				{  clickState = QUARTER_WEIGHT; } } );

      // Change to THREEQUARTER_WEIGHT
		threeQuarterWeightClick.addActionListener( new ActionListener () {
				public void actionPerformed(ActionEvent e)
				{  clickState = THREEQUARTER_WEIGHT; } } );

      // Change to FULL_WEIGHT
		fullWeightClick.addActionListener( new ActionListener () {
				public void actionPerformed(ActionEvent e)
				{  clickState = FULL_WEIGHT; } } );

      // Change to ANCHORPLUS
		anchorPlusClick.addActionListener( new ActionListener () {
				public void actionPerformed(ActionEvent e)
				{  clickState = ANCHORPLUS; } } );

      // Change to PADPLUS
		padPlusClick.addActionListener( new ActionListener () {
				public void actionPerformed(ActionEvent e)
				{  clickState = PADPLUS; } } );

      // Change to PADMINUS
		padMinusClick.addActionListener( new ActionListener () {
				public void actionPerformed(ActionEvent e)
				{  clickState = PADMINUS; } } );

      // Change to INSETSPLUS
		insetsPlusClick.addActionListener( new ActionListener () {
				public void actionPerformed(ActionEvent e)
				{  clickState = INSETSPLUS; } } );

      // Change to INSETSMINUS
		insetsMinusClick.addActionListener( new ActionListener () {
				public void actionPerformed(ActionEvent e)
				{  clickState = INSETSMINUS; } } );

      // Set weight to 0
		noWeight.addActionListener(
			new ActionListener ()
			{
				public void actionPerformed(ActionEvent e)
				{
               GridBagConstraints gbc1 = new GridBagConstraints();
               int buttonCount = gridBagPanel.getComponentCount();
               Component component;

               for(int i=0; i<buttonCount; i++)
               {
                  component = gridBagPanel.getComponent(i);
                  gbc1 = gridBagLayout.getConstraints(component);
                  gbc1.weightx = 0;
                  gbc1.weighty = 0;
                  gridBagLayout.setConstraints(component, gbc1);
               }

               gridBagLayout.invalidateLayout(gridBagPanel);
               gridBagLayout.layoutContainer(gridBagPanel);
				}
			}
		);




      // Set weight to 1
		fullWeight.addActionListener(
			new ActionListener ()
			{
				public void actionPerformed(ActionEvent e)
				{
               GridBagConstraints gbc1 = new GridBagConstraints();
               int buttonCount = gridBagPanel.getComponentCount();
               Component component;

               for(int i=0; i<buttonCount; i++)
               {
                  component = gridBagPanel.getComponent(i);
                  gbc1 = gridBagLayout.getConstraints(component);
                  gbc1.weightx = 1;
                  gbc1.weighty = 1;
                  gridBagLayout.setConstraints(component, gbc1);
               }

               gridBagLayout.invalidateLayout(gridBagPanel);
               gridBagLayout.layoutContainer(gridBagPanel);
				}
			}
		);


	}



	public static void main( String args[])
	{
		GridBagLayoutTest gridBagTest = new GridBagLayoutTest();
		gridBagTest.setSize(640, 480);
		gridBagTest.show();
	}

	public void windowClosing(WindowEvent event)
	{
		System.exit(0);
	}

	public void actionPerformed(ActionEvent e)
	{
		Object o = e.getSource();
		if(! (o instanceof Button))
			return;

		Button currentButton = (Button)o;

		if(clickState >= NO_WEIGHT && clickState <= FULL_WEIGHT)
		{
			GridBagConstraints gbc1 = new GridBagConstraints();
				gbc1 = gridBagLayout.getConstraints(currentButton);

			switch(clickState)
		{
            case  NO_WEIGHT:
               gbc1.weightx = 0;
               gbc1.weighty = 0;
               break;

            case  QUARTER_WEIGHT:
               gbc1.weightx = .25;
               gbc1.weighty = .25;
               break;

            case  THREEQUARTER_WEIGHT:
               gbc1.weightx = .75;
               gbc1.weighty = .75;
               break;

            case  FULL_WEIGHT:
               gbc1.weightx = 1;
               gbc1.weighty = 1;
               break;
            }

            gridBagLayout.setConstraints(currentButton, gbc1);
         }

         else if(clickState == FONTPLUS || clickState == FONTMINUS)
         {
   			Font font = currentButton.getFont();
   			int fontSize = font.getSize();
            if (clickState == FONTPLUS)
   			   fontSize += 10;
            else if (fontSize > 10)
               fontSize -= 10;
            else
               fontSize = 10;
               
   			currentButton.setFont(new Font(font.getName(),
   								font.getStyle(),
   								fontSize));
         }

         else if(clickState >= FILLMINUS && clickState <= FILLPLUS)
         {
            GridBagConstraints gbc1 = new GridBagConstraints();
            gbc1 = gridBagLayout.getConstraints(currentButton);

            switch(clickState)
            {
            case  FILLMINUS:
               gbc1.fill = GridBagConstraints.NONE;
               break;

            case  FILLVERT:
               gbc1.fill = GridBagConstraints.VERTICAL;
               break;

            case  FILLHORZ:
               gbc1.fill = GridBagConstraints.HORIZONTAL;
               break;

            case  FILLPLUS:
               gbc1.fill = GridBagConstraints.BOTH;
               break;
		}

            gridBagLayout.setConstraints(currentButton, gbc1);

	   }
	   else if (clickState == ANCHORPLUS)
	   {
            GridBagConstraints gbc1 = new GridBagConstraints();
            gbc1 = gridBagLayout.getConstraints(currentButton);
            if(gbc1.anchor == GridBagConstraints.NORTHWEST)
			gbc1.anchor = GridBagConstraints.NORTH;  
		else if(gbc1.anchor == GridBagConstraints.NORTH)
			gbc1.anchor = GridBagConstraints.NORTHEAST;  
		else if(gbc1.anchor == GridBagConstraints.NORTHEAST)
			gbc1.anchor = GridBagConstraints.EAST;  
		else if(gbc1.anchor == GridBagConstraints.EAST)
			gbc1.anchor = GridBagConstraints.SOUTHEAST;  
		else if(gbc1.anchor == GridBagConstraints.SOUTHEAST)
			gbc1.anchor = GridBagConstraints.SOUTH;  
		else if(gbc1.anchor == GridBagConstraints.SOUTH)
			gbc1.anchor = GridBagConstraints.SOUTHWEST;  
		else if(gbc1.anchor == GridBagConstraints.SOUTHWEST)
			gbc1.anchor = GridBagConstraints.WEST;  
		else if(gbc1.anchor == GridBagConstraints.WEST)
			gbc1.anchor = GridBagConstraints.CENTER;  
		else if(gbc1.anchor == GridBagConstraints.CENTER)
			gbc1.anchor = GridBagConstraints.NORTHWEST;  

            gridBagLayout.setConstraints(currentButton, gbc1);
	   }
	   else if (clickState == PADPLUS || clickState == PADMINUS)
	   {
            GridBagConstraints gbc1 = new GridBagConstraints();
            gbc1 = gridBagLayout.getConstraints(currentButton);
		if(clickState == PADPLUS)
		{
			gbc1.ipadx += 5;
			gbc1.ipady += 5;
		}
		else if(gbc1.ipadx >= 5 && gbc1.ipady >= 5)
		{
			gbc1.ipadx -= 5;
			gbc1.ipady -= 5;
		}
		gridBagLayout.setConstraints(currentButton, gbc1);

	   }
	   else if (clickState == INSETSPLUS || clickState == INSETSMINUS)
	   {
            GridBagConstraints gbc1 = new GridBagConstraints();
            gbc1 = gridBagLayout.getConstraints(currentButton);

		if(clickState == INSETSPLUS)
		{
			gbc1.insets.top += 5;
			gbc1.insets.bottom += 5;
			gbc1.insets.left += 5;
			gbc1.insets.right += 5;
		}
		else if(gbc1.insets.top >= 5)
		{
			gbc1.insets.top -= 5;
			gbc1.insets.bottom -= 5;
			gbc1.insets.left -= 5;
			gbc1.insets.right -= 5;
		}
		gridBagLayout.setConstraints(currentButton, gbc1);

	   }
	updateTest();	



	}

	public void updateTest()
	{
		gridBagPanel.repaint();		
		borderLayout.layoutContainer(this);
		gridBagLayout.invalidateLayout(gridBagPanel);
		gridBagLayout.layoutContainer(gridBagPanel);
		repaint();
	}

	// Unused WindowListener interface
	public void windowOpened(WindowEvent event) {}
	public void windowClosed(WindowEvent event) {}
	public void windowIconified(WindowEvent event) {}
	public void windowDeiconified(WindowEvent event) {}
	public void windowActivated(WindowEvent event) {}
	public void windowDeactivated(WindowEvent event) {}

}






