/******************************************************************************/
/* COPYRIGHT: Copyright (C) International Business Machines Corp., 1997       */
/*                                                                            */
/* DISCLAIMER OF WARRANTIES:                                                  */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is not part of any standard IBM product   */
/*   and is provided to you solely for the purpose of assisting you in the    */
/*   development of your applications.  The code is provided "AS IS",         */
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
/******************************************************************************/

import java.awt.*;
import java.awt.event.*;

class diagonalLayout implements LayoutManager
{
  private int preferredWidth;
  private int preferredHeight;
  private int _marginx;
  private int _marginy;

  public diagonalLayout()
  {
    _marginx = 0;
    _marginy = 0;
  }

  public diagonalLayout(int marginx, int marginy)
  {
    _marginx = marginx;
    _marginy = marginy;
  }

  public void addLayoutComponent(String name, Component comp) {}

  public void removeLayoutComponent(Component comp) {}

  public Dimension preferredLayoutSize(Container parent)
  {
    Insets insets = parent.getInsets();
    Component c;
    Dimension d;
    Dimension dim = new Dimension(0,0);
    int numComp = parent.getComponentCount();

    for (int i=0; i<numComp; i++)
    {
      c = parent.getComponent(i);
      if (c.isVisible())
      {
        d = c.getPreferredSize();
        dim.width += d.width;
        dim.height += d.height;
      }
    }
    dim.width += insets.left + insets.right;
    dim.height += insets.top + insets.bottom;
    return dim;
  }

  public Dimension minimumLayoutSize(Container parent)
  {
     Insets insets = parent.getInsets();
     Component c;
     Dimension d;
     Dimension dim = new Dimension(0,0);
     int numComp = parent.getComponentCount();
 
     for (int i=0; i<numComp; i++)
     {
       c = parent.getComponent(i);
       if (c.isVisible())
       {
         d = c.getMinimumSize();
         dim.width += d.width;
         dim.height += d.height;
       }
     }
     dim.width += insets.left + insets.right;
     dim.height += insets.top + insets.bottom;
     return dim;
  }

  public void layoutContainer(Container parent) 
  {
    Insets insets = parent.getInsets();
    int numComp = parent.getComponentCount();
    int containerWidth = parent.getSize().width - insets.left - insets.right;
    int containerHeight = parent.getSize().height - insets.top - insets.bottom;
    Component c;
    int startx = insets.left;
    int starty = insets.top;
    int compWidth;
    int compHeight;

    for (int i=0; i<numComp; i++)
    {
      c = parent.getComponent(i);
      if (c.isVisible())
      {
        compWidth = c.getPreferredSize().width;
        compHeight = c.getPreferredSize().height;
        c.setBounds(startx, starty, compWidth, compHeight);
        startx += compWidth + _marginx;
        starty += compHeight + _marginy;
      }
    }
  }
}

class custom2 extends Frame {         
  public custom2()
  {
    setTitle("custom2");
    setLayout(new diagonalLayout(5, 2));
    add(new Button("OK"));
    add(new Button("Cancel"));
    add(new Checkbox("Checkbox"));
    List l = new List(4);
    l.add("Pebble Beach");
    l.add("Augusta National");
    l.add("Spyglass Hill");
    l.add("PGA National");
    l.add("TPC Sawgrass");
    add(l);
    add(new Button("Button"));
    
    class custom2LayoutTestAdapter extends WindowAdapter
    {
      public void windowClosing(WindowEvent event) 
      {
        System.exit(0);
      }
    }
    addWindowListener(new custom2LayoutTestAdapter());
  }
  
  public static void main(String args[])
  {
    Frame f = new custom2();
    f.setSize(300,300);
    f.show();
  }
}
