/******************************************************************************/
/* COPYRIGHT: Copyright (C) International Business Machines Corp., 1997       */
/*                                                                            */
/* DISCLAIMER OF WARRANTIES:                                                  */
/*   The following [enclosed] code is sample code created by IBM              */
/*   Corporation.  This sample code is not part of any standard IBM product   */
/*   and is provided to you solely for the purpose of assisting you in the    */
/*   development of your applications.  The code is provided "AS IS",         */
/*   without warranty of any kind.  IBM shall not be liable for any damages   */
/*   arising out of your use of the sample code, even if they have been       */
/*   advised of the possibility of such damages.                              */
/******************************************************************************/

import java.awt.event.*;
import java.awt.*;
import java.io.*;


//
//class golfInfoDlg: Golf Information Dialog - This dialog class is used to collect the information about 
//a round of golf.  It uses GridBagLayout to display the dialog.
//
class golfInfoDlg extends Dialog 
                  implements ActionListener
{
  private Button cancelButton;

  public golfInfoDlg(Frame parent) 
  {
    super(parent, "Golf Score Information", true);  
    class golfInfoDlgWindowAdapter extends WindowAdapter
    {
      public void windowClosing(WindowEvent event) 
      {
        dispose();
      }
    }
    addWindowListener(new golfInfoDlgWindowAdapter());    
    
    //Use the GridBagLayout for this dialog
    GridBagLayout gbl = new GridBagLayout();
    GridBagConstraints gbc = new GridBagConstraints();
    setLayout(gbl);
    
    //To use the GridBagLayout, we set up the constraints for each component, add the constraints to the component,
    //then add the component to the GridBagLayout.
    
    Label golfCourseListLabel = new Label("Golf Courses");
    gbc.anchor = GridBagConstraints.SOUTH;
    gbc.fill = GridBagConstraints.NONE;
    addComponentToGridBag(golfCourseListLabel, gbl, gbc, 0, 0, 1, 1);
    
    FileReader fis2 = null;
    //Read the golf courses from the file and place in a list box.
    try {
    fis2 = new FileReader("courses.lst");
    }
    catch (FileNotFoundException e3)
    {
      messageBox mb = new messageBox("The file: " + (e3.getMessage()).toUpperCase() + " was not found.");
      mb.show();
    }
    
    BufferedReader in2 = new BufferedReader(fis2); 
    List golfCourseList = new List(4, false);
    String dataString = null;
    try {
    dataString = in2.readLine();
    }                              
    catch (IOException e4)
    {System.exit(0);}
    
    while (dataString != null)
    {
      golfCourseList.addItem(dataString);
      try {
      dataString = in2.readLine();
      }
      catch (IOException e7)
      {System.exit(0);}
    }
    
    //Setup GridBagConstraints and add the component
    gbc.anchor = GridBagConstraints.CENTER;
    gbc.fill = GridBagConstraints.BOTH; 
    gbc.weighty = 100;
    addComponentToGridBag(golfCourseList, gbl, gbc, 0, 2, 1, 3);

    Panel statPanel = new Panel();    
    statPanel.setLayout(new GridLayout(4,2));
    Label score = new Label("Score");
    TextField tfScore = new TextField(2);
    Label fairways = new Label("Fairways");
    TextField tfFairways = new TextField(2);
    Label greens = new Label("Greens");    
    TextField tfGreens = new TextField(2);
    Label putts = new Label("Putts");  
    TextField tfPutts = new TextField(2);
    statPanel.add(score);
    statPanel.add(tfScore);
    statPanel.add(fairways);
    statPanel.add(tfFairways);
    statPanel.add(greens);
    statPanel.add(tfGreens);
    statPanel.add(putts);
    statPanel.add(tfPutts);
    
    gbc.anchor = GridBagConstraints.CENTER;
    gbc.fill = GridBagConstraints.NONE; 
    gbc.weighty = 0;
    addComponentToGridBag(statPanel, gbl, gbc, 1, 0, 2, 4);
    
    TextField courseNotInList = new TextField();
    gbc.anchor = GridBagConstraints.SOUTH;
    gbc.fill = GridBagConstraints.HORIZONTAL;
    gbc.weightx = 100;
    addComponentToGridBag(courseNotInList, gbl, gbc, 0, 5, 3, 1);
                                      
    Panel buttonPanel = new Panel();
    Button okButton = new Button("OK");
    buttonPanel.add(okButton);
    cancelButton = new Button("Cancel");
    buttonPanel.add(cancelButton);
    
    cancelButton.addActionListener(this);
    okButton.addActionListener(this);
        
    //Setup GridBagConstraints
    gbc.anchor = GridBagConstraints.SOUTH;
    gbc.fill   = GridBagConstraints.HORIZONTAL;
    gbc.weightx = 0;
    addComponentToGridBag(buttonPanel, gbl, gbc, 0, 6, 3, 1);
  }
  
  public void actionPerformed(ActionEvent event) 
  {
    if (event.getSource() == cancelButton)
    {
      dispose();
    }
  }
  
  //
  //Helper function to set the most volatile GridBagConstraints.
  //
  private void addComponentToGridBag(Component c, GridBagLayout gbl, GridBagConstraints gbc, int x, int y, int w, int h)
  {
    gbc.gridx = x;
    gbc.gridy = y;
    gbc.gridwidth = w;
    gbc.gridheight = h;
    gbl.setConstraints(c, gbc);
    add(c);
  }
}

//
// class messageBox: This class implements a message box. 
//
class messageBox extends Dialog implements ActionListener
{
  public messageBox(String str)
  {
    super (new Frame(), "ERROR", true);
  
    class messageBoxWindowAdapter extends WindowAdapter
    {
      public void windowClosing(WindowEvent event) 
      {
        dispose();
      }
    }
     
    Panel p1 = new Panel();
    p1.add(new Label(str));
    add("Center", p1);
    Panel p2 = new Panel();
    Button btn = new Button("OK"); 
    btn.addActionListener(this);
    p2.add(btn);
    add("South", p2);
    setSize(300, 200);
  }
  public void actionPerformed(ActionEvent event) 
  {
    dispose();
  }
}

//
// class golfStats: class to display main window with menu etc.  This class also contains the main()
//
class gridbagtest extends Frame 
                  implements ActionListener
{
   private MenuItem miNewStats;
   private MenuItem miQuit;

  public gridbagtest()
  {
    setTitle("GridBagLayout test program");
    MenuBar menuBar = new MenuBar();
    Menu menu = new Menu("File");
    menu.addActionListener(this);
    miNewStats = new MenuItem("Enter New Golf Round Stats");
    menu.add(miNewStats);
    miNewStats.addActionListener(this);
    menu.addSeparator();
    miQuit= new MenuItem("Quit");
    menu.add(miQuit);
    miQuit.addActionListener(this);
    menuBar.add(menu);
    setMenuBar(menuBar);
   
    class golfWindowAdapter extends WindowAdapter
    {
      public void windowClosing(WindowEvent event) 
      {
        System.exit(0);
      }
    }
    addWindowListener(new golfWindowAdapter());
  }

  public void actionPerformed(ActionEvent event)
  {
    if (event.getSource() == miQuit)
    {
      System.exit(0);
    }
    else if (event.getSource() == miNewStats)
    {
      fDialog = new golfInfoDlg(this); 
      fDialog.setSize(300,300);
      fDialog.show();
    } 
  }
  private golfInfoDlg fDialog;
  
  //
  // main
  //
  public static void main(String args[])
  {
    Frame gbt = new gridbagtest();
    gbt.setSize(300, 200);
    gbt.show();
  }
}
